/**************************************************************

   Program Title:  
   
   Program Name: WP12_LCD.h 		  Version: 0.01
   
   Author:  SS/WR	  				  Date:  Febuary 29th, 2008
   
   Compiled with ImageCraft ICCAVR Standard V7.1
   
   Copyright 2004-2008, SOC Machines, Inc.  All rights reserved.
   
****************************************************************/
/*
 * Copyright (C) 2008 by SOC Machines, Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the copyright holders nor the names of
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 * 4. Redistribution is only allowed in combination with SOC Machines, 
 *    Inc. hardware products.
 *
 * THIS SOFTWARE IS PROVIDED BY SOC MACHINES, INC. AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL SOC MACHINES, 
 * INC. OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
 * THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * For additional information see http://www.soc-machines.com
 */


// Clear display - move cursor to home
#define    LCDCLR	0x01

// E1010 and E1007 Commands
#define	   LCDCHIPE1010 0x10
#define    LCDCHIPE1007 0x07   

// move cursor to home position command
#define    LCDHOME   	0x10  

// Static Display Command
//   D1/0 - 0,0  Display OFF
//   D1/0 - 0,1  1-2Hz blink
//   D1/0 - 1,0  3-4Hz blink
//   D1/0 - 1,1  Display ON
#define    LCDSTATICDISPLAY	0x20 
#define    LCDDISPLAYON  	0x03
#define    LCDDISPLAYOFF	0x00 

// Display control command
//   D3-C, D2-B, D1-DC, D0-D
//   C  -> 1 cursor on, 0 off
//   DC -> 1 double cursor on, 0 off
//   B  -> 1 blink on, 0 off
//   D  -> 1 display on, 0 off	 
#define    LCDDISPLAY          0x30 
#define    LCDCURSORON	       0x08
#define    LCDCURSOROFF        0x00
#define    LCDCURSORBLINK      0x04 
#define    LCDCURSONNOBLINK    0x00
#define    LCDCURSORDISPLAYON  0x01
#define    LCDCURSORDISPLAYOFF 0x00

// Power Save Command
//   D1-O, D0-PS
//   PS -> 1 power save on, 0 off
//   O  -> 1 oscillator circuit on, 0 off
#define	   LCDPOWERSAVE    0x40
#define    LCDPOWERSAVEON  0x01
#define    LCDPOWERSAVEOFF 0x00
#define    LCDOSCON		   0x02
#define    LCDOSCOFF	   0x00

// Power supply control
//   D2-VC, D1-VF, D0-P
//   VC -> 1 voltage regulator on, 0 off
//   VF -> 1 voltage follower on, 0 off
//   P  -> 1 voltage booster on, 0 off
#define    LCDPOWERSUPPLY   0x50
#define	   LCDVOLTREGON     0x04
#define	   LCDVOLTREGOFF    0x00
#define	   LCDVOLTFOLLOWON  0x02
#define	   LCDVOLTFOLLOWOFF 0x00
#define	   LCDVOLTBOOSTON   0x01
#define	   LCDVOLTBOOSTOFF  0x00

// System set command
//   D3-N2, D2-N1, D0-CG
//   N2/1 -> 0,0  2 lines
//   N2/1 -> 0,1  3 lines
//   N2/1 -> 1,0  4 lines
//   CG   -> 1 CGRAM used, 0 not used
#define    LCDSYSTEMSET  0x60
#define    LCD4LINE		 0x08
#define    LCDCGON		 0x01

// Electronic volume setting
//   D3-0 - set display brightness
#define    LCDVOLREG 0x70  

// Set address of DDRAM, CGRAM or symbol register
#define    LCDRAMADDRESS  0x80 

//  LCD chip select is active low
#define	   CS       2
//  LCD Command/Data  0 - command, 1 data
#define    LA0      1
//  LCD reset line - active high to reset
#define    LCDRESET 3
//  LCD Serial Data Line
#define    LCD_SI   0
//  LCD Serial Clock
#define    LCD_SCLK 4

#define    LCDCONTROL PORTB
#define    LCDDATA    PORTB
#define    LINE1 	  0x30
#define	   LINE2	  0x40
#define	   LINE3	  0x50
#define	   LINE4	  0x60

#define    TAB		  0x09
#define    CRLF       0x10
#define    TITLE      0x01

// LCD defines
#define  LCD_BATTERY_FULL    6
#define  LCD_BATTERY_THREEQUARTER 5 
#define  LCD_BATTERY_HALF    4
#define  LCD_BATTERY_QUARTER 3
#define  LCD_BATTERY_EMPTY   2
#define  LCD_BATTERY_OFF     1

#define  LCD_ANTENNA_FULL    6
#define  LCD_ANTENNA_THREEQUARTER  5
#define  LCD_ANTENNA_HALF    4
#define  LCD_ANTENNA_QUARTER 3 
#define  LCD_ANTENNA_EMPTY   2
#define  LCD_ANTENNA_OFF     1

#define  LCD_PHONE_ON		 1
#define  LCD_SLASHPHONE		 2
#define  LCD_PHONE_OFF		 3

#define  LCD_PHONE_SYMBOL      0x02
#define  LCD_BIGANTENNA_SYMBOL 0x08

#define  NO_ACTIVE_STATE 0
#define  ANTENNA_STATE  1
#define  BATTERY_STATE  2
#define  VSYM_STATE     3
#define  DSYM_STATE     4
#define  RSYM_STATE     5
#define  ENVELOPE_STATE 6
#define  PHONE_STATE    7
#define  TWI_ADDRESS_STATE 8
#define  LCD_SYMBOL_STATE 9
#define  LED_BLINK_STATE 10
#define  VOLTAGE_STATE  11



#define 	NO  		  0x00
#define 	YES 		  0x01
#define 	ON  		  0x01
#define 	OFF 		  0x00
#define 	DEBUG 		  0
#define 	XON   		  0x11
#define 	XOFF  		  0x13
#define 	LF	  		  0x0A
#define 	CR	  		  0x0D
#define     ESC			  0x1B
#define  	SPACE 	   	  0x20


#define SetBit(x,y) (x|=(1<<y)) 
#define ClrBit(x,y) (x&=~(1<<y)) 


void LCDWriteSerialByte(unsigned char inchar);
void LCDprintchar(unsigned char inchar);
void LCDwritecommand(unsigned char inchar);
void LCDDisplayChar(unsigned char address, unsigned char inchar);
void LCD_Write(unsigned char address,unsigned char data);
void LCDdisplays(unsigned char address, char *instrg);
void LCDprints(char *instrg);
void LCD_Symbols(unsigned char state);
void SetBuffers(unsigned char inchar);
void Clear_LCD();
void Init_LCD();
void DisplayLCDBuffers();
void LoadSignon();
void ShiftUpLine();
void PutCharinBuffer(unsigned char row,unsigned char address,unsigned char inchar);
void LCD_Dsymbol(unsigned char state);
void LCD_Rsymbol(unsigned char state);
void LCD_Vsymbol(unsigned char state);
void LCD_Phone(unsigned char state);
void LCD_Envelope(unsigned char state);
void LCD_Battery(unsigned char level);
void LCD_Antenna(unsigned char level);
unsigned char GetRowfromLine(unsigned char line);
void SendCharToDisplay(unsigned char inchar);
void IncrementLinePtr();
void ParseEscSubCommand(unsigned char inchar);
void ParseSymbolCommand(unsigned char inchar);
void ParseEscCommand(unsigned char inchar);
void ParseChar(unsigned char inchar);
void ParseStrg(unsigned char *instrg);
void PutStringinBuffer(unsigned char row,unsigned char column,char *strg);
unsigned char GetLine(unsigned char row);
void Display_Voltage_Volume(unsigned char row,unsigned char column);
void Display_Voltage_Reference(unsigned char row,unsigned char column);
void Adjust_VoltageVolume();
void Display_Display_Parameters();
void DisplayPointPattern();
void Display_Count();
void SplashScreen();
void bytetoint(unsigned char byte);
void DisplayTime(unsigned char row,unsigned char column);









void Delay(void);
void ShortDelay(int cnt);
void LongDelay(int cnt);
void Delaymsec(int delayvalue);
unsigned char hextobyte(unsigned char inbyte);
//  Convert byte to ASCII hex
void bytetohex(unsigned char byte);


